@@ -1,9 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "pimdatacommandlineoption.h"
+#include "config-pimdataexporter.h"
 #include "pimdataexporter-version.h"
 #include "pimdataexporterwindow.h"
 #include "pimdataexportgui_debug.h"
@@ -38,7 +39,7 @@ void PimDataCommandLineOption::createParser(const QApplication &app)
                          QStringLiteral(PIMDATAEXPORTER_VERSION),
                          i18n("PIM Data Exporter"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2012-%1 pimdataexporter authors", QStringLiteral("2024")));
+                         i18n("Copyright © 2012-%1 pimdataexporter authors", QStringLiteral("2025")));
     aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
     aboutData.setupCommandLine(&mParser);
@@ -49,7 +50,7 @@ void PimDataCommandLineOption::createParser(const QApplication &app)
     mParser.addOption(QCommandLineOption(QStringList() << QStringLiteral("export"), i18nc("@info:shell", "Export the given file")));
     mParser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"),
                                          i18nc("@info:shell", "File or url. The user will be asked whether to import or export.")));
-#ifdef WITH_KUSERFEEDBACK
+#if PIMDATAEXPORTER_WITH_KUSERFEEDBACK
     mParser.addOption(QCommandLineOption(QStringLiteral("feedback"), i18nc("@info:shell", "Lists the available options for user feedback")));
 #endif
     mParser.process(app);
