@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -45,7 +45,7 @@
 #include <QVBoxLayout>
 
 #include "dialog/pimdataexporterconfiguredialog.h"
-#ifdef WITH_KUSERFEEDBACK
+#if PIMDATAEXPORTER_WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
 #include <KUserFeedback/Provider>
@@ -83,7 +83,7 @@ PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
 #endif
     // Initialize filtermanager
     (void)MailCommon::FilterManager::instance();
-#ifdef WITH_KUSERFEEDBACK
+#if PIMDATAEXPORTER_WITH_KUSERFEEDBACK
     // Initialize
     (void)UserFeedBackManager::self();
 #endif
@@ -113,7 +113,7 @@ PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
     statusBar()->hide();
     mTrayIcon = new PimDataTrayIcon(this);
-#ifdef WITH_KUSERFEEDBACK
+#if PIMDATAEXPORTER_WITH_KUSERFEEDBACK
     auto userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
     userFeedBackNotificationPopup->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
 #endif
